#[non_exhaustive]pub enum DualStatus {
NoSolution,
FeasiblePoint,
Unknown,
}Expand description
Availability and quality of the dual solution returned by a solver.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NoSolution
The backend reports that no dual solution is available.
FeasiblePoint
A usable dual point is available.
Unknown
The backend cannot distinguish unavailable from unreported duals.